# bioleach-balrog

An alternate version of [bioleach](https://pypi.org/project/bioleach/) that uses the machine-learning based method [balrog](https://github.com/salzberg-lab/BalrogCPP) for gene prediction.

In general, refer to the [bioleach documentation](https://aaylward.gitlab.io/bioleach) , as usage of `bioleach-balrog` is identical to `bioleach` except that it substitutes Balrog for Prodigal in the gene prediction step.

See documentation specific to `bioleach-balrog` here: [bioleach-balrog documentation](https://aaylward.gitlab.io/bioleach-balrog).

## Installation

The suggested method for installing bioleach-balrog is via pip in a dedicated conda environment

```sh
conda create -n bioleach -c conda-forge -c bioconda \
  pandas seaborn biopython sra-tools pysradb \
  mysql-connector-python sqlalchemy fastp kraken2 bowtie2 \
  samtools megahit prodigal numpy=2.3 pytorch mmseqs2 balrog
pip install bioleach-balrog
```

After installing, confirm you have the latest version

```sh
bioleach-balrog --version
```
